<?php
/**
 * Apis functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, antiaris_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *  
 *     remove_filter('filter_hook', 'callback_function' );
 *     ...
 * }
 * </code>
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 * @subpackage Antiaris
 * @since antiaris 1.0
 */


/**
 * Retrieve the theme's user settings and default settings. Individual files can access
 * these setting via a global variable call, so database query is only
 * done once.
 *
*/
include('admin/options-defaults.php');
$antiaris_settings = get_option('antiaris_settings');


/**
 * If there is no theme settings in the database yet (e.g. first install), add the database entry.
*/
if (!function_exists('antiaris_db_init')) :
	function antiaris_db_init(){
		global $antiaris_settings, $antiaris_defaults;
		if (!$antiaris_settings || (count($antiaris_settings) != count($antiaris_defaults))) {
			$initial_settings = array();
			
			// Add all the deafult settings if no setting in the database yet
			if (!$antiaris_settings){
				$initial_settings = $antiaris_defaults;
				update_option('antiaris_settings', $initial_settings);
			} else {
			
				// Construct the updated settings
				foreach ($antiaris_defaults as $option => $value) :
					$initial_settings[$option] = (array_key_exists($option, $antiaris_settings)) ? $antiaris_settings[$option] : $value;
				endforeach;
				
				// Add the initial settings to the database
				update_option('antiaris_settings', $initial_settings);
			}
			// Update the global $antiaris_settings;
			$antiaris_settings = $initial_settings;
		}
	}
endif;
add_action('init', 'antiaris_db_init');


/*
echo '<pre>';
print_r($antiaris_defaults);
print_r($antiaris_settings);
echo '</pre>';
*/


/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * Used to set the width of images and content. Should be equal to the width the theme
 * is designed for, generally via the style.css stylesheet.
 */
if (!isset($content_width)){
	if ((!is_active_sidebar('left-widget-area') || $antiaris_settings['disable_left_sidebar']) && $antiaris_settings['disable_right_sidebar'])
		// one-column layout
		$content_width = apply_filters('antiaris_one_column_content_width', 920);
	elseif ((is_active_sidebar('left-widget-area') && !$antiaris_settings['disable_left_sidebar']) && !$antiaris_settings['disable_right_sidebar'])
		// three-column layout
		$content_width = apply_filters('antiaris_three_column_content_width', 480);
	else
		// two-column layout
		$content_width = apply_filters('antiaris_two_column_content_width', 600);
}


/** Tell WordPress to run antiaris_setup() when the 'after_setup_theme' hook is run. */
add_action('after_setup_theme', 'antiaris_setup');

if (!function_exists( 'antiaris_setup')):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override antiaris_setup() in a child theme, add your own antiaris_setup to your child theme's
 * functions.php file.
 *
 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_custom_background() To add support for a custom background.
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_custom_image_header() To add support for a custom header.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since antiaris 1.0
 */
function antiaris_setup() {
	global $antiaris_settings, $antiaris_defaults;

	// Define the theme's database version
	define('ANTIARIS_DBVERSION', 1.0);
	
	// Add the theme's dbversion in the database if none exist
	if (!get_option('antiaris_dbversion')) {update_option('antiaris_dbversion', ANTIARIS_DBVERSION);}
	
	// Add support for editor syling
	add_editor_style();
	
	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Make theme available for translation
	// Translations can be filed in the /languages/ directory
	load_theme_textdomain('antiaris', get_template_directory().'/languages');
	
	// Add new image sizes to be used with the theme
	add_image_size('antiaris-archive-thumb', 150, 100, true);
	$height = ($antiaris_settings['slider_height']) ? $antiaris_settings['slider_height'] : $antiaris_defaults['slider_height'];
	add_image_size('antiaris-medium-slider', apply_filters('antiaris_medium_slider_image_width', 555), $height, true);
	add_image_size('antiaris-full-slider', apply_filters('antiaris_full_slider_image_width', 960), $height, true);
	add_image_size('antiaris-homepage-pane', apply_filters('antiaris_homepage_pane_image_width', 290), apply_filters('antiaris_homepage_pane_image_height', 170), true);
	
	//Register the custom menus
	register_nav_menus( array(
		'header-menu' => __('Header Menu', 'antiaris'),
		'secondary-menu' => __('Secondary Menu', 'antiaris'),
		'footer-menu' => __('Footer Menu', 'antiaris'),
	) );
	
	// This theme allows users to set a custom background
	add_custom_background();
	
	
	/* Set the constants required for the custom header function */
	define('NO_HEADER_TEXT', apply_filters('antiaris_header_text', false));
	define('HEADER_TEXTCOLOR', apply_filters('antiaris_header_textcolor', 'CADBF4'));
	define('HEADER_IMAGE', apply_filters('antiaris_header_image', '%s/images/header-default.png')); // %s is the template dir uri
	define('HEADER_IMAGE_WIDTH', apply_filters('antiaris_header_image_width', 960)); // use width and height appropriate for your theme
	define('HEADER_IMAGE_HEIGHT', apply_filters('antiaris_header_image_height', 150));
	
	// Add a way for the custom header to be styled in the admin panel that controls
	// custom headers. See antiaris_admin_header_style(), below.
	add_custom_image_header('', 'antiaris_admin_header_style');
	
	// Register the default header
	register_default_headers(array(
		'Default Header' => array(
			'url' => '%s/images/header-default.png',
			'thumbnail_url' => '%s/images/header-default-thumb.png',
			'description' => __('The default header image for the theme', 'antiaris')
		),
	));
	
	do_action('antiaris_setup');
}
endif;


/**
 * Register and print the main theme stylesheet
*/
function antiaris_main_stylesheet(){
	wp_register_style('antiaris-stylesheet', get_stylesheet_uri(), array(), false, 'screen');
	wp_register_style('googlefont-cuprum', 'http://fonts.googleapis.com/css?family=Cuprum', array(), false, 'all');
	
	wp_enqueue_style('googlefont-cuprum');
	wp_enqueue_style('antiaris-stylesheet');
}
add_action('wp_print_styles', 'antiaris_main_stylesheet');


/**
 * Enqueue style for the theme's options page
*/
if (!function_exists('antiaris_admin_options_style')) :
	function antiaris_admin_options_style() {
		wp_enqueue_style('antiaris-admin-style');
		if (is_rtl()) {wp_enqueue_style('antiaris-admin-style-rtl');}
	}
endif;


/** 
 * Adds the theme options page
*/
function antiaris_options_init() {
	$antiaris_options = add_theme_page(__('Antiaris Options', 'antiaris'), __('Antiaris Options', 'antiaris'), 'edit_theme_options', 'antiaris_options', 'antiaris_options');	
	
	// Register the style for the theme's options page
	wp_register_style('antiaris-admin-style', get_template_directory_uri().'/admin/admin.css');
	if (is_rtl()) {wp_register_style('antiaris-admin-style-rtl', get_template_directory_uri().'/admin/admin-rtl.css');}
	
	// Print the style for the theme's options page
	add_action('admin_print_styles-'.$antiaris_options, 'antiaris_admin_options_style');
	
	// Action hook for additional customisations
	do_action('antiaris_options_init');
}
add_action('admin_menu', 'antiaris_options_init');

// Include the file that handles the options page
include('admin/options.php');


if (!function_exists('antiaris_admin_header_style')) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 * Referenced via add_custom_image_header() in antiaris_setup().
 *
 * @since antiaris 1.0
 */
function antiaris_admin_header_style(){ ?>
	<style type="text/css">
		#headimg{
			height:160px;
			position:relative;
			background-repeat:repeat-x;
		}
		#headimg #name, #headimg #desc{
			position:absolute;
			text-align:right;
			right:50px;
			top:50px;
			font:normal 34px cuprum, georgia;
			text-shadow:1px 2px 2px #031829;
		}
		#headimg #desc{
			top:90px;
			right:50px;
			font:italic 20px Georgia;
			color:#729EE2;
			}
		#headimg #name, #headimg #name:visited{
			color:#CADBF4;
			text-decoration:none;
			}
    </style>
    
	<?php
	do_action('antiaris_admin_header_style');
}
endif;


/**
 * Register widgetized areas
 *
 * To override antiaris_widgets_init() in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @since antiaris 1.0
 * @uses register_sidebar
 */
function antiaris_widgets_init() {
	global $antiaris_settings, $antiaris_defaults;
	$footer_widget_count = ($antiaris_settings['footer_widget_count']) ? $antiaris_settings['footer_widget_count'] : $antiaris_defaults['footer_widget_count'];
	
	if (function_exists('register_sidebar')) {
		
		// Left sidebar
		$name = ($antiaris_settings['disable_left_sidebar']) ? __('Left Sidebar (disabled)', 'antiaris') : __('Left Sidebar', 'antiaris');
		register_sidebar(array(
			'name' => $name,
			'id' => 'left-widget-area',
			'description' => __( 'The left sidebar widget area.', 'antiaris' ),
			'before_widget' => '<div class="sidebar-item-wrap clearfix">',
			'after_widget' => '</div>',
			'before_title' => "<h3>",
			'after_title' => "</h3>",
		));
		
		if ($antiaris_settings['enable_alternate_left_sidebar']) :
			register_sidebar(array(
				'name' =>  __('Left Sidebar (front page)', 'antiaris'),
				'id' => 'left-frontpage-widget-area',
				'description' => __( 'The left sidebar widget area that will only be displayed on the front page.', 'antiaris' ),
				'before_widget' => '<div class="sidebar-item-wrap clearfix">',
				'after_widget' => '</div>',
				'before_title' => "<h3>",
				'after_title' => "</h3>",
			));
		endif;
		
		// Right sidebar
		$name = ($antiaris_settings['disable_right_sidebar']) ? __('Right Sidebar (disabled)', 'antiaris') : __('Right Sidebar', 'antiaris');
		register_sidebar(array(
			'name' => $name,
			'id' => 'right-widget-area',
			'description' => __( 'The right sidebar widget area.', 'antiaris' ),
			'before_widget' => '<div class="sidebar-item-wrap clearfix">',
			'after_widget' => '</div>',
			'before_title' => "<h3>",
			'after_title' => "</h3>",
		));
		
		if ($antiaris_settings['enable_alternate_right_sidebar']) :
			register_sidebar(array(
				'name' =>  __('Right Sidebar (front page)', 'antiaris'),
				'id' => 'right-frontpage-widget-area',
				'description' => __( 'The right sidebar widget area that will only be displayed on the front page.', 'antiaris' ),
				'before_widget' => '<div class="sidebar-item-wrap clearfix">',
				'after_widget' => '</div>',
				'before_title' => "<h3>",
				'after_title' => "</h3>",
			));
		endif;
		
		// Footer sidebar
		for ($i = 1; $i <= $footer_widget_count; $i++) :
		$name = (!$antiaris_settings['disable_footer_widget']) ? sprintf(__('Footer Widget Area %d', 'antiaris'), $i) : sprintf(__('Footer Widget Area %d (disabled)', 'antiaris'), $i);
		register_sidebar(array(
			'name' => $name,
			'id' => 'footer-widget-area-'.$i,
			'description' => sprintf(__("The footer widget area (column %d).", 'antiaris'), $i),
			'before_widget' => '<div class="sidebar-item-wrap clearfix">',
			'after_widget' => '</div>',
			'before_title' => "<h3>",
			'after_title' => "</h3>",
		));
		
		if ($antiaris_settings['enable_alternate_footer_widget']) :
			register_sidebar(array(
				'name' => $name.' '.__('(front page)', 'antiaris'),
				'id' => 'footer-frontpage-widget-area-'.$i,
				'description' => sprintf(__("The footer widget area that will only be displayed on the front page (column %d).", 'antiaris'), $i),
				'before_widget' => '<div class="sidebar-item-wrap clearfix">',
				'after_widget' => '</div>',
				'before_title' => "<h3>",
				'after_title' => "</h3>",
			));
		endif;
		endfor;
		
		
		/* Header widget area */
		if ($antiaris_settings['enable_header_widget']) :
			register_sidebar(array(
				'name' => __('Header Widget Area', 'antiaris'),
				'id' => 'header-widget-area',
				'description' => __("The header widget area.", 'antiaris'),
				'before_widget' => '<div class="sidebar-item-wrap clearfix">',
				'after_widget' => '</div>',
				'before_title' => "<h3>",
				'after_title' => "</h3>",
			));
		endif;
		
		/**
		 * Register alternate widget areas to be displayed on the front page, if enabled
		 *
		 * @package WordPress
		 * @subpackage antiaris
		 * @since antiaris 1.0
		*/
		/*
		if (get_option('antiaris_alt_home_sidebar')) {
			register_sidebar(array(
				'name' => __('Sidebar Widget Area (Front Page)', 'antiaris'),
				'id' => 'sidebar-widget-area-home',
				'description' => __( 'The right sidebar widget area that will only be displayed on the front page.', 'antiaris' ),
				'before_widget' => '<div class="sidebar-wrap clearfix">',
				'after_widget' => '</div>',
				'before_title' => "<h3>",
				'after_title' => "</h3>",
			));
		}
		
		if (get_option('antiaris_alt_home_footerwidget')) {
			register_sidebar(array(
				'name' => __('Front Page Footer Widget Area', 'antiaris'),
				'id' => 'home-footer-widget-area',
				'description' => __( "The footer widget area that will only be displayed on the front page. Leave empty to disable. Set the number of columns to display at the theme's Display Options page.", 'antiaris' ),
				'before_widget' => '<div class="sidebar-wrap clearfix">',
				'after_widget' => '</div>',
				'before_title' => "<h3>",
				'after_title' => "</h3>",
			));
		}
		*/
	}
	
	do_action('antiaris_widgets_init');
}
/** Register sidebars by running antiaris_widgets_init() on the widgets_init hook. */
add_action('widgets_init', 'antiaris_widgets_init');



/**
 * This functions adds additional classes to the <body> element. The additional classes
 * are added by filtering the Wordpress body_class() function.
*/
function antiaris_body_class($classes){
	global $antiaris_settings;
	
	// Check if both left and right sidebar is active (3 columns)
	if ((is_active_sidebar('left-widget-area') && !$antiaris_settings['disable_left_sidebar']) && !$antiaris_settings['disable_right_sidebar']) {
		$classes[] = 'three-column';
	}
	
	// Check if both sidebar is not active (one column)
	elseif ((!is_active_sidebar('left-widget-area') || $antiaris_settings['disable_left_sidebar']) && $antiaris_settings['disable_right_sidebar']) {
		$classes[] = 'one-column';
	}
	
	// Two-column layout. Also checks which sidebar is active
	else {
		if ($antiaris_settings['disable_left_sidebar'] || (!$antiaris_settings['disable_left_sidebar'] && !is_active_sidebar('left-widget-area'))){
			$classes[] = 'sidebar-right';
		}
		if ($antiaris_settings['disable_right_sidebar']){
			$classes[] = 'sidebar-left';
		}
	}
	
	// Check if a static front page is being used
	if (get_option('show_on_front') == 'page' && is_front_page()){
		$classes[] = 'static-front-page';	
	}
	
	// Prints the body class
	return $classes;
}
add_filter('body_class', 'antiaris_body_class');



/**
 * Register and enqueue the TinyDropdown menu script
*/
function antiaris_tinydropdown_js(){
	wp_enqueue_script('tiny-dropdown', get_template_directory_uri().'/js/tinydropdown.js', array(), '', true);
}
add_action('template_redirect', 'antiaris_tinydropdown_js');


/**
 * Add the TinyDropdown initialisation script
*/
function antiaris_tinydropdown_script(){ ?>
	<script type="text/javascript">
	<!--
	var menu1 = new menu.dd('menu1');
	menu1.init('header-menu', 'menuhover');
	
	var menu2 = new menu.dd('menu2');
	menu2.init('secondary-menu', 'menu2hover');
	//-->
	</script>
<?php
}
add_action('wp_footer', 'antiaris_tinydropdown_script');


/**
 * Defines the callback function menu for the primary menu, if there is no custom primary menu defined.
 * This menu automatically lists all Pages as menu items, including their descendants.
*/
if (!function_exists('antiaris_default_menu')) :
	function antiaris_default_menu(){ ?>
        <ul id="header-menu" class="menu clearfix">
        <?php if (get_option('show_on_front') == 'posts') : ?>
       		<li <?php if ( is_single() || is_front_page()) { echo 'class="current_page_item"'; } ?>><a href="<?php echo get_home_url(); ?>"><?php _e('Home','antiaris'); ?></a></li>
        <?php endif; ?>
        <?php wp_list_pages(array('echo' => 1, 'sort_column' => 'menu_order', 'depth' => 0, 'title_li' => '')); ?>
        </ul>
	<?php	
		do_action('antiaris_default_menu');
	} 
endif;


/**
 * Defines the callback function menu for the secondary menu, if there is no custom secondary menu defined.
 * This menu automatically lists all Categories as menu items, including their descendants.
*/
if (!function_exists('antiaris_default_secondary_menu')) :
	function antiaris_default_secondary_menu(){ ?>
    	
        <ul id="secondary-menu" class="menu clearfix">
		<?php wp_list_categories(array('title_li' => '', 'depth' => 0)); ?>
		</ul>
        
        <?php
		do_action('antiaris_default_secondary_menu');
	} 
endif;



/**
 * Defines the callback function for use with wp_list_comments(). This function controls
 * how comments are displayed.
*/
if (!function_exists('antiaris_comments')) :
	function antiaris_comments($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment; ?>
        
		<li id="comment-<?php comment_ID(); ?>" <?php comment_class('clearfix'); ?>>
        	<?php /* Comment author avatar */ ?>
			<?php echo get_avatar($comment, apply_filters('antiaris_comments_avatar_size', 40)); ?>
            
            <?php /* Support for comment numbering using Greg's Threaded Comment Numbering plugin */ ?>
            <?php if (function_exists('gtcn_comment_numbering')) {gtcn_comment_numbering($comment->comment_ID, $args);} ?>
            
            <?php /* Comment metadata */ ?>
			<div class="comment-info">
				<p class="comment-author"><cite><?php comment_author_link() ?></cite>:</p>
				<p class="comment-reply-link"><?php comment_reply_link(array('depth' => $depth, 'max_depth' => $args['max_depth'], 'reply_text' => __('Reply', 'antiaris'))); ?></p>
				<p class="commentmetadata"><?php printf(__('%1$s at %2$s (GMT %3$s)','antiaris'), get_comment_date(), get_comment_time(), get_comment_time('O')); ?> <?php edit_comment_link(__('Edit comment','antiaris'),' | ',''); ?></p>
			</div>
            
            <?php /* Comment entry */ ?>
			<div class="comment-entry">
				<?php if ($comment->comment_approved == '0') : ?>
				   <p><em><?php _e('Your comment is awaiting moderation.','antiaris') ?></em></p>
				<?php endif; ?>
				<?php comment_text(); ?>
			</div>
	<?php
	}
endif;


/**
 * Get the  most popular posts based on number of comments and return the list
*/
function antiaris_popular_posts($before = '<li>', $after = '</li>', $show_pass_post = false, $duration='') {
	global $wpdb, $antiaris_settings, $antiaris_defaults;
	
	$no_posts = ($antiaris_settings['popularpost_count'] != '') ? $antiaris_settings['popularpost_count'] : $antiaris_defaults['popularpost_count'];
	
	$request = "SELECT ID, post_title, post_date, COUNT($wpdb->comments.comment_post_ID) AS 'comment_count' FROM $wpdb->posts, $wpdb->comments";
	$request .= " WHERE comment_approved = '1' AND $wpdb->posts.ID=$wpdb->comments.comment_post_ID AND post_status = 'publish'";
	if (!$show_pass_post) {$request .= " AND post_password =''";}
	if ($duration != "") {$request .= " AND DATE_SUB(CURDATE(),INTERVAL ".$duration." DAY) < post_date ";}
	$request .= " GROUP BY $wpdb->comments.comment_post_ID ORDER BY comment_count DESC LIMIT $no_posts";
	
	$posts = $wpdb->get_results($request);
	$output = '';
	
	if ($posts) { global $post;
		foreach ($posts as $post) {
			$post_title = stripslashes($post->post_title);
			// $date = mysql2date(__("F j, Y",'antiaris'), strtotime($post->post_date));
			$date = get_the_date();
			$comment_count = $post->comment_count;
			$permalink = get_permalink($post->ID);
			$output .= $before . '<p class="tab-right-post-title"><a href="'.$permalink.'">'.$post_title.'</a></p>';
			$output .= '<p>'. sprintf(_n('<a href="%1$s#comments">%2$d comment</a> since %3$s','<a href="%1$s#comments">%2$d comments</a> since %3$s', $comment_count, 'antiaris'), $permalink, $comment_count, $date).'</p>'.$after;
		}
	} else {
		$output .= $before . __("None found",'antiaris') . $after;
	}
	
	return $output;
}


/**
 * Get the most recent comments
*/
function antiaris_recent_comments($status = 'approve', $count = 5){
	
	// Get the latest comments based on the parameters
	$args = apply_filters('antiaris_summarypanel_latestcomments_args', array(
																	  'status' => $status,
																	  'number' => $count,
																	  'order' => 'DESC',
																	  'type' => 'comment',
																			));
	$comments = get_comments($args);
	
	// Format the comments into list
	$output = '';
	
	foreach ($comments as $comment):
		$output .= '<li>' . sprintf(__('%1$s on %2$s', 'antiaris'),  '<a href="'.get_comment_link($comment->comment_ID).'">'.$comment->comment_author.'</a>', '<a href="'.get_permalink($comment->comment_post_ID)).'">'.get_the_title($comment->comment_post_ID).'</a><br />';
		$output .= substr(strip_tags($comment->comment_content), 0, 70);
		if (strlen(strip_tags($comment->comment_content)) > 70) {$output .= ' &hellip;';}
		$output .= '</li>';
	endforeach;
	
	return $output;
}


/**
 * Displays the Site Summary panel
*/
if (!function_exists('antiaris_site_summary')) :
	function antiaris_site_summary(){ global $antiaris_settings, $antiaris_defaults; ?>
    
        <div id="tab" class="clearfix">
        
        	<?php /* Show full slider instead of site summary if enabled in options */
            if ($antiaris_settings['show_slider']) :
				antiaris_slider('full');
            else :
			/* Otherwise show the Site Summary Panel */
			?>
            
				<?php /* The left side of the Site Summary panel */ ?>
                <div id="tabs-left" <?php if ($antiaris_settings['left_tab_shows'] == 'posts-slider') {echo 'class="tabs-slider"';} ?>>
                
                    <?php 
                        if ($antiaris_settings['left_tab_shows'] == 'categories-latest-post')
                            antiaris_cats_latest_post();
                        elseif (($antiaris_settings['left_tab_shows'] == 'posts-slider'))
                            antiaris_slider('medium');
                    
                    ?>
                    
                </div><!--#tabs-left-->
                
                
                <?php /* The right side of the Site Summary panel */ ?>
                <div id="tabs-right">
                    <ul id="tab-right-links" class="tab-links">
                        <li><a href="#"><span><?php _e('Latest','antiaris'); ?></span></a></li>
                        <li><a href="#"><span><?php _e('Popular','antiaris'); ?></span></a></li>
                        <li><a href="#"><span><?php _e('Comments','antiaris'); ?></span></a></li>
                        <li><a href="#"><span><?php _e('Tags','antiaris'); ?></span></a></li>
                    </ul>
                    
                    <?php /* The latest posts */ ?>
                    <div class="tabcontent">
                        <ul>
                            <?php 
							global $post;
                            $latestpost_count = ($antiaris_settings['latestpost_count'] != '') ? $antiaris_settings['latestpost_count'] : $antiaris_defaults['latestpost_count'];
							$args = array(
										  'numberposts' => $latestpost_count,
										  'orderby' => 'date',
										  'order' => 'DESC',
										  'suppress_filters' => 0,
										  'post_type' => 'post'
										  );
                            $posts = get_posts(apply_filters('antiaris_site_summary_latest_posts_args', $args)); ?>
                                            
                            <?php foreach ($posts as $post) : setup_postdata($post); ?>
                            <li>
                                <p class="tab-right-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></p>
                                <p><?php
                                printf(__('%1$s since %2$s %3$s','antiaris'), 
                                comments_popup_link(__('No comment','antiaris'), __('1 comment','antiaris'), __("% comments", 'antiaris')), 
                                get_the_date(), get_the_time());
                                ?></p>
                            </li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                    
                    <?php /* The most popular posts */ ?>
                    <div class="tabcontent">
                        <ul>
                            <?php echo antiaris_popular_posts(); ?>
                        </ul>
                    </div>
                    
                    <?php /* The most recent comments */ ?>
                    <div class="tabcontent">
                        <ul>
                            <?php
                            $latestcomment_count = ($antiaris_settings['latestcomment_count'] != '') ? $antiaris_settings['latestcomment_count'] : $antiaris_defaults['latestcomment_count'];
                            echo antiaris_recent_comments('approve', $latestcomment_count); 
                            ?>
                        </ul>
                    </div>
                    <div class="tabcontent">
                        <?php 
                        $tag_number = ($antiaris_settings['tags_count'] != '') ? $antiaris_settings['tags_count'] : $antiaris_defaults['tags_count'];
                        wp_tag_cloud("smallest=8&largest=15&format=list&number=$tag_number");
                        ?>
                    </div>
                </div><!--#tabs-right-->
                
            <?php endif; ?>
        </div><!--#tabs-->
    <?php
	}
endif;

/**
 * The function that displays the latest post from each selected category
 * in the site summary panel
*/
if (!function_exists('antiaris_cats_latest_post')) :
	function antiaris_cats_latest_post(){ global $antiaris_settings, $antiaris_defaults;
		
		/* Get the list of categories to be displayed from the theme's settings */
		$categories = (is_array($antiaris_settings['latestpost_cats']) && array_key_exists('latestpost_cats', $antiaris_settings)) ? $antiaris_settings['latestpost_cats'] : $antiaris_defaults['latestpost_cats']; ?>
		<ul id="tab-cat-links" class="tab-links">
			<?php foreach ($categories as $category) : ?>
			<li><a href="#"><?php echo get_cat_name($category); ?></a></li>
			<?php endforeach; ?>
		</ul>
		
		<?php /* Get the latest post from each of the category selected above */
		foreach ($categories as $category) : global $post; ?>
		<?php 
		$args = array(
					  'cat' => $category,
					  'numberposts' => 1,
					  'order' => 'DESC'
					  );
		$posts = get_posts(apply_filters('antiaris_site_summary_cat_latest_posts_args', $args)); ?>
			<?php foreach ($posts as $post) : setup_postdata($post); ?>
			<div class="tabcontent">
				<h2 class="tab-post-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
				<p class="tab-post-meta"><?php 
				global $authordata;
				/* translators: %1$s will be replaced by the post date, %2$s the post time, and %3$s the post author */
				printf(__('%1$s at %2$s by %3$s','antiaris'), get_the_date('', $post->ID), get_the_time('', $post->ID), '<a href="'.get_author_posts_url($authordata->ID).'">'.get_the_author().'</a>');
				?></p>
				<div class="tab-post-content clearfix">
					<?php /* The post thumbnail */
					echo antiaris_archive_post_image(get_the_ID(), 'thumbnail'); ?>
					
					<?php /* The post's truncated content */ ?>
					<?php echo wpautop(get_the_excerpt()); ?>
					<p class="read-more"><a class="more-link" href="<?php the_permalink(); ?>"><?php _e('Continue reading &raquo;','antiaris'); ?></a></p>
				</div>
				
				<?php /* Comments and categories links */ ?>
				<div class="tab-post-footer clearfix">
					<p class="tab-post-comment"><?php comments_popup_link(__('No comment','antiaris'), __('1 comment','antiaris'), __("% comments", 'antiaris')); ?></p>
					<p class="cat-more"><?php _e('More in ','antiaris'); the_category(', '); ?></p>
				</div>
			</div>
			<?php endforeach; ?>
		<?php endforeach;
	}
endif;


/**
 * The function that displays the slider in the Site Summary panel
*/
if (!function_exists('antiaris_slider')) :
	function antiaris_slider($mode = 'medium'){ 
		global $antiaris_settings, $antiaris_defaults;
		
		do_action('antiaris_before_slider'); ?>
    
        <div class="featured_slider <?php if ($mode == 'full') {echo 'featured-slider-full';}?>">
            <?php do_action('antiaris_before_slideritems'); ?>
            <div id="slider_root">
                <div class="slider_items">
        <?php 
            /**
             * Get the featured posts to be displayed on the slider
            */
            global $post;
            
            /**
             * Get the category whose posts should be displayed here. If no 
             * category is defined, the 5 latest posts will be displayed
            */
            $slidercat = ($antiaris_settings['slider_cat'] != '') ? $antiaris_settings['slider_cat'] : false;
            
            /* Get the posts to display in the slider */
            if (!$slidercat) {						
                
                // Get the number of posts to show
                $postcount = ($antiaris_settings['slider_postcount']) ? $antiaris_settings['slider_postcount'] : $antiaris_defaults['slider_postcount'];
                
				$args = array(
						  'numberposts' => $postcount,
						  'orderby' => 'date',
						  'order' => 'DESC',
						  'suppress_filters' => 0,
						  'post_type' => 'post'
						 );
		
                $sliderposts = get_posts(apply_filters('antiaris_slider_posts_latest_args', $args));
            } else {
				
				$args = array(
						  'category' => $slidercat,
						  'orderby' => 'date',
						  'order' => 'DESC',
						  'suppress_filters' => 0,
						  'post_type' => 'post',
						  'nopaging' => true
						 );
                $sliderposts = get_posts(apply_filters('antiaris_slider_posts_args', $args));
            }
                
            /* Display each post in the slider */	
            foreach ($sliderposts as $post) :
                setup_postdata($post);
				?>
                
                <?php /* The slider image as background. This is so that the first image is preloaded */
				
				/* Don't need this for now
				$image_size = ($mode == 'medium') ? 'antiaris-medium-slider' : 'antiaris-full-slider';
                    if (has_post_thumbnail($post->ID)) {
                        $slider_img = antiaris_get_post_thumbnail_uri($post->ID, $image_size);
						$slider_img = $slider_img[0];
                    } else {
                        $slider_img = antiaris_get_post_image($post->ID, $image_size, true);
						$slider_img = $slider_img[0];
                    }
					$style = 'style="background-image:url('.$slider_img.');"';
				*/
				?>
                
                <div class="slider_post clearfix" <?php // echo $style; ?>>
                
                    <?php do_action('antiaris_before_sliderpost'); ?>            
                    
                    <?php /* The slider image as <img> */ 
					$image_size = ($mode == 'medium') ? 'antiaris-medium-slider' : 'antiaris-full-slider';
					if (has_post_thumbnail($post->ID)) {
                        $slider_img = get_the_post_thumbnail($post->ID, $image_size);
                    } else {
                        $slider_img = antiaris_get_post_image($post->ID, $image_size);
                    }
					echo $slider_img;
					?>
                    
                    <?php /* The slider post's title (for full-sized slider) */ ?>
					<?php if ($mode == 'full') : ?>
                    <h2 class="slider-post-title"><?php the_title(); ?></h2>
                    <?php endif; ?>
                    
                    <div class="slider-post-content-block clearfix">
						
                        <?php if ($mode == 'medium') : ?>
						<div class="left-wrap">
                        <?php endif; ?>
							
							<?php /* The slider post's title (for medium-sized slider) */ ?>
                            <?php if ($mode == 'medium') : ?>
                            <h2 class="slider-post-title"><?php the_title(); ?></h2>
                            <?php endif; ?>
                            
                            <?php /* The slider's excerpt */ ?>
                            <?php if ($mode == 'full') : ?>
                            <div class="slider-post-excerpt">
                            	<?php echo wpautop(get_the_excerpt()); ?>
                            </div>
                            <?php endif; ?>
                            
                            <?php /* The slider post's author */ global $authordata; ?>
                            <p class="slider-post-author"><?php printf(__('Written by %s', 'antiaris'), '<a href="'.get_author_posts_url($authordata->ID).'">'.get_the_author().'</a>'); ?></p>
                            
                        <?php if ($mode == 'medium') : ?>
                        </div>
                        <?php endif; ?>
                        
                        <?php /* The slider post's read more button */ ?>
                        <p class="slider-post-read-more">
                            <a href="<?php the_permalink(); ?>"><?php _e('Read the story', 'antiaris'); ?></a>
                        </p>
                    </div>
                </div>
            <?php	
            endforeach;
            
        ?>
                </div>
            </div>
            
            <?php /* The slider navigation */ ?>
            <div class="slider_nav">
                <?php $i = 0; foreach ($sliderposts as $post) : ?>
                <a href="#" <?php if ($i == 0) {echo ' class="active"';} ?>><span><?php the_title(); ?></span></a>
                <?php $i++; endforeach; ?>
                
                <?php do_action('antiaris_slider_nav'); ?>
            </div>
            
        </div>
        <?php
		
	/* Print the slider JavaScript to the footer */
	add_action('wp_footer', 'antiaris_slider_js');
		
	}
endif;


/**
 * Prints out the scripts required for the featured posts slider. The featured
 * posts slider uses jQuery and jQuery Tools plugin.
*/
if (!function_exists('antiaris_slider_js')) :
	function antiaris_slider_js() { 
		global $antiaris_settings, $antiaris_defaults;
		
		$interval = ($antiaris_settings['slider_speed']) ? $antiaris_settings['slider_speed'] : $antiaris_defaults['slider_speed'];
		if (is_front_page()) : ?>
            <!-- Scrollable -->
            <script type="text/javascript">
                jQuery(document).ready(function($){
												
					<?php if (!$antiaris_settings['show_slider']) : ?>							
					$(function() {
                        // initialize scrollable
						$("#slider_root").scrollable({circular: true}).navigator({	  
								navi: ".slider_nav",
								naviItem: 'a',
								activeClass: 'active'
							}).autoscroll({interval: <?php echo $interval; ?>});
                    });
					
					<?php else : ?>
					
					$(function() {
                        // setup ul.tabs to work as tabs for each div directly under div.panes
                        $("div.slider_nav").tabs("div.slider_items > div", {tabs: 'a', effect: 'fade', fadeInSpeed: 500, fadeOutSpeed: 700, rotate: true, current: 'active'
						}).slideshow({autoplay: true, interval: <?php echo $interval; ?>});
                    });
					<?php endif; ?>
					
                });
            </script>
            <!-- #Scrollable -->
            
		<?php 
		endif;
	}
endif;


/**
 * Load the Site Summary Panel. If you want to customise in which pages the summary panel
 * is displayed, create your own antiaris_display_summarypanel() function to overwrite this
 * function.
*/
if (!function_exists('antiaris_display_summarypanel')) :
	function antiaris_display_summarypanel(){ global $antiaris_settings;
		if (is_front_page() && !$antiaris_settings['disable_summarypanel']) {antiaris_site_summary();}
	}
endif;
add_action('antiaris_summarypanel', 'antiaris_display_summarypanel');


/**
 * jQuery Tabs
*/
if (!function_exists('antiaris_tabs')) :
	function antiaris_tabs() { global $antiaris_settings, $antiaris_defaults;
		if (is_front_page()) : ?>
            <!-- Tabs -->
            <script type="text/javascript">
                jQuery(document).ready(function($){
                    $(function() {
                        // setup ul.tabs to work as tabs for each div directly under div.panes
                        $("ul#tab-cat-links").tabs("div#tabs-left > div", {effect: 'fade', fadeInSpeed: 400, fadeOutSpeed: 400,rotate: true
						<?php $interval = ($antiaris_settings['summarypanel_left_duration']) ? $antiaris_settings['summarypanel_left_duration'] : $antiaris_defaults['summarypanel_left_duration']; ?>
						}).slideshow({autoplay: true, interval: <?php echo $interval; ?>});
                    });
					$(function() {
                        // setup ul.tabs to work as tabs for each div directly under div.panes
                        $("ul#tab-right-links").tabs("div#tabs-right > div", {effect: 'fade', fadeInSpeed: 400, fadeOutSpeed: 400, rotate: true
						<?php $interval = ($antiaris_settings['summarypanel_right_duration']) ? $antiaris_settings['summarypanel_right_duration'] : $antiaris_defaults['summarypanel_right_duration']; ?>
						}).slideshow({autoplay: true, interval: <?php echo $interval; ?>});
                    });
                });
            </script>
            <!-- #Tabs -->
		<?php 
		endif;
	}
endif;

// Load jQuery Tools script
function antiaris_tabs_js() {
	wp_enqueue_script('antiaris-jquery-tools', 'http://cdn.jquerytools.org/1.2.5/all/jquery.tools.min.js', array('jquery'), false, true);
}

// Print both the js and the script
add_action('template_redirect', 'antiaris_tabs_js');
add_action('wp_footer', 'antiaris_tabs');


/**
 * Sets the various customised styling according to the options set for the theme
*/
function antiaris_custom_style(){ 
	global $antiaris_settings, $antiaris_defaults, $content_width; 
	
	$panel_height = ($antiaris_settings['summarypanel_height']) ? $antiaris_settings['summarypanel_height'] : $antiaris_defaults['summarypanel_height'];
	if ($antiaris_settings['show_slider']) {$panel_height = $antiaris_settings['slider_height'];}
	?>
    
	<style type="text/css">
		.post{max-width:<?php echo $content_width; ?>px;}
		#header{height:<?php echo HEADER_IMAGE_HEIGHT; ?>px;}
		#tab{height:<?php echo $panel_height; ?>px;}
		
		<?php /* Load the custom CSS styles from the theme's options page */
		echo stripslashes($antiaris_settings['custom_css']);
		?>
    </style>
    
<?php 
	do_action('antiaris_custom_style');
}
add_action('wp_head', 'antiaris_custom_style', 90);


/**
 * Generates the posts navigation links
*/
if (!function_exists('antiaris_posts_nav')) :
	function antiaris_posts_nav(){ 
		if ((get_option('show_on_front') != 'page' || !is_front_page()) && (get_previous_posts_link() || get_next_posts_link())) : ?>
		<div class="post-nav clearfix">
        	<?php if (get_next_posts_link()) : ?>
			<p id="previous"><?php next_posts_link(__('Older posts', 'antiaris')) ?></p>
            <?php endif; ?>
            
            <?php if (get_previous_posts_link()) : ?>
			<p id="next-post"><?php previous_posts_link(__('Newer posts', 'antiaris')) ?></p>
            <?php endif; ?>
		</div>
        
        <?php do_action('antiaris_posts_nav'); ?>
	<?php
		endif;
	}
endif;


/**
 * Generates the post navigation links
*/
if (!function_exists('antiaris_post_nav')) :
	function antiaris_post_nav(){ 
		if (is_single() && !is_page()) : ?>
		<div class="post-nav clearfix">
			<?php next_post_link('<p id="previous">%link</p>') ?>
			<?php previous_post_link('<p id="next-post">%link</p>') ?>
		</div>
        
        <?php do_action('antiaris_post_nav'); ?>
	<?php
		endif;
	}
endif;


/**
 * Adds the functionality to count comments by type, eg. comments, pingbacks, tracbacks.
 * Based on the code at WPCanyon (http://wpcanyon.com/tipsandtricks/get-separate-count-for-comments-trackbacks-and-pingbacks-in-wordpress/)
 *
 * @package WordPress
 * @subpackage Antiaris
 * @since Antiaris 1.0
*/
function antiaris_comment_count($type = 'comments', $noneText = '', $oneText = '', $moreText = ''){

	if($type == 'comments') :
		$typeSql = 'comment_type = ""';
	elseif($type == 'pings') :
		$typeSql = 'comment_type != ""';
	elseif($type == 'trackbacks') :
		$typeSql = 'comment_type = "trackback"';
	elseif($type == 'pingbacks') :
		$typeSql = 'comment_type = "pingback"';
	endif;

	global $wpdb;

    $result = $wpdb->get_var('
        SELECT
            COUNT(comment_ID)
        FROM
            '.$wpdb->comments.'
        WHERE
            '.$typeSql.' AND
            comment_approved="1" AND
            comment_post_ID= '.get_the_ID()
    );

	if($result == 0):
		return str_replace('%', $result, $noneText);
	elseif($result == 1): 
		return str_replace('%', $result, $oneText);
	elseif($result > 1): 
		return str_replace('%', $result, $moreText);
	endif;
}

/**
 * Enqueue the jQuery Tools Tabs JS and the necessary script for comments/pings tabs
*/
function antiaris_tabs_comments_js(){ ?>
	<script type="text/javascript">
		jQuery(document).ready(function($){
			$(function(){
				$("div#comments").tabs("div#comments > ol", {tabs: 'h3', effect: 'fade'});
			});
		});
	</script>
<?php
}
add_action('wp_footer', 'antiaris_tabs_comments_js');



/**
 * Customise the comment form
*/

// Start with the default fields
function antiaris_comment_form_fields(){
	$fields =  array(
		'author' => '<p class="comment-form-author"><label for="author" class="antiaris_form_label">'.__('Name:','antiaris').'</label><input id="author" name="author" type="text" /></p>',
		'email'  => '<p class="comment-form-email"><label for="email" class="antiaris_form_label">' . __('Email:','antiaris').'</label><input id="email" name="email" type="text" /></p>',
		'url'    => '<p class="comment-form-url"><label for="url" class="antiaris_form_label">'.__('Website:','antiaris').'</label><input id="url" name="url" type="text" /></p>',
	);
	
	do_action('antiaris_comment_form_fields');
	
	return $fields;
}

// The comment field textarea
function antiaris_comment_textarea(){
	echo '<div class="comment-form-message clearfix"><label class="antiaris_form_label">'.__('Message:','antiaris').'</label><textarea name="comment" id="comment" cols="40" rows="10" tabindex="4"></textarea></div>';
	
	do_action('antiaris_comment_textarea');
}

// Add all the filters we defined
add_filter('comment_form_default_fields', 'antiaris_comment_form_fields');
add_filter('comment_form_field_comment', 'antiaris_comment_textarea');


/**
 * This function gets the URL of post thumbnail.
 * Returns an array containing: [0] => Image URL, [1] => Image width, [2] => Image height
*/
function antiaris_get_post_thumbnail_uri($post_id = NULL, $size = 'thumbnail'){
	if ($post_id == NULL){
		_e('ERROR: antiaris_get_post_thumbnail_uri() function requires the post ID to be passed as an argument.');
		return;
	}
	$src = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), $size);
	return $src;
}


/**
 * This function gets the first image (as ordered in the post's media gallery) attached to
 * the current post. It outputs the complete <img> tag, with height and width attributes.
 * The function returns the thumbnail of the original image, linked to the post's 
 * permalink. Returns FALSE if the current post has no image.
 *
 * This function requires the post ID to get the image from to be supplied as the
 * argument. If no post ID is supplied, it outputs an error message. An optional argument
 * size can be used to determine the size of the image to be used.
 *
 * Based on code snippets by John Crenshaw 
 * (http://www.rlmseo.com/blog/get-images-attached-to-post/)
 *
 * @package WordPress
 * @subpackage Antiaris
 * @since Antiaris 1.0
*/
if (!function_exists('antiaris_get_post_image')) :
	function antiaris_get_post_image($post_id = NULL, $size = 'thumbnail', $url_only = false){
		
		/* Display error message if no post ID is supplied */
		if ($post_id == NULL){
			_e('<strong>ERROR: You must supply the post ID to get the image from as an argument when calling the antiaris_get_post_image() function.</strong>', 'antiaris');
			return;
		}
		
		/* Get the images */
		$args = array(
				  'post_type' 		=> 'attachment',
				  'post_mime_type' 	=> 'image',
				  'post_parent' 	=> $post_id,
				  'orderby'			=> 'menu_order',
				  'order'			=> 'ASC',
				  'numberposts'		=> 1,
					   );
		$images = get_children(apply_filters('antiaris_get_post_image_args', $args), ARRAY_A);
		
		
		/* Returns FALSE if there is no image */
		if (empty($images)) {
			return FALSE;
		}
		
		/* Build the <img> tag if there is an image */
		$out = '';
		
		if (!$url_only) {
			foreach ($images as $image){
				$out .= '<a href="'.get_permalink($post_id).'">';
				$out .= wp_get_attachment_image($image['ID'], $size);
				$out .= '</a>';
			}
		} else {
			foreach ($images as $image){
				$out = wp_get_attachment_image_src($image['ID'], $size);
			}
		}
		
		/* Returns the image HTMl */
		return $out;
}
endif;



/**
 * Add the post thumbnail or the thumbnail of the first image in post for
 * archive pages.
*/
if (!function_exists('antiaris_archive_post_image')) :
	function antiaris_archive_post_image($post_id){
		$html = '';
		$size = apply_filters('antiaris_archive_thumb_size', 'antiaris-archive-thumb');
		
		// Return the post thumbnail if exists
		if (has_post_thumbnail($post_id)){
			$html .= '<div class="archive-thumb">';
			$html .= get_the_post_thumbnail($post_id, $size);
			$html .= '</div>';
		} else {
		// Otherwise return the first image in post
			$html .= '<div class="archive-thumb">';
			$html .= antiaris_get_post_image($post_id, $size);
			$html .= '</div>';
		}
		
		return $html;	
	}
endif;


/**
 * Prints the social sharing code if enabled
*/
function antiaris_print_social_sharing(){
	global $antiaris_settings;
	if (!is_page() || $antiaris_settings['enable_social_sharing_inpage']) {
		echo $antiaris_settings['social_sharing_code'];
	}
}
if ($antiaris_settings['enable_social_sharing'])
	add_action('antiaris_social_sharing', 'antiaris_print_social_sharing');
	


/**
 * Prints the Google Analytics code if enabled
*/
function antiaris_print_analytics(){
	global $antiaris_settings;
	echo $antiaris_settings['analytics_code'];
}
if ($antiaris_settings['enable_analytics'])
	add_action('wp_head', 'antiaris_print_analytics', 100);
	

/**
 * Output the Google Adsense code if enabled
*/
$adsense_count = 0;
function antiaris_print_adsense(){ 
	global $antiaris_settings, $adsense_count; 
	$adsense_count++;
?>
	<div class="adsense">
	<?php if ($adsense_count < 4 || $antiaris_settings['enable_adsense_premium']) {echo $antiaris_settings['adsense_code'];} ?>
    </div>
<?php
}
if ($antiaris_settings['enable_adsense'])
	add_action('antiaris_after_post', 'antiaris_print_adsense');
	
	
/**
 * Add filter to have the title displayed as (no title) if
 * the post doesn't have a title
*/
function antiaris_post_title($title){
	$title = ($title) ? $title : __('(No title)', 'antiaris');
	return $title;
}
add_filter('the_title', 'antiaris_post_title', 10, 1);


/**
 * This function prints out the title for the website.
 * If present, the theme will display customised site title structure.
*/
if (!function_exists('antiaris_title')) :
	function antiaris_title(){
		global $antiaris_settings;
		
		if (is_front_page()) { 
			if ($antiaris_settings['custom_site_title_frontpage']) {
				$title = $antiaris_settings['custom_site_title_frontpage'];
				$title = str_replace('#site-name', get_bloginfo('name'), $title);
				$title = str_replace('#site-desc', get_bloginfo('description'), $title);
			} else {
				$title = get_bloginfo('name') . " &raquo; " . get_bloginfo('description');
			}
			
		} else {
			if ($antiaris_settings['custom_site_title_content']) {
				$title = $antiaris_settings['custom_site_title_content'];
				$title = str_replace('#site-name', get_bloginfo('name'), $title);
				$title = str_replace('#site-desc', get_bloginfo('description'), $title);
				$title = str_replace('#post-title', wp_title('', false), $title);
			} else {
				$title = wp_title('', false)." &raquo; ".get_bloginfo('name');
			}
		}
		
		echo $title;
	}
endif;


/*
 * Adds a menu-item-ancestor class to menu items with children for styling.
 * Code taken from the Menu-item-ancestor plugin by Valentinas Bakaitis
*/
function antiaris_add_ancestor_class($classlist, $item){
	global $wp_query, $wpdb;
	//get the ID of the object, to which menu item points
	$id = get_post_meta($item->ID, '_menu_item_object_id', true);
	//get first menu item that is a child of that object
	$children = $wpdb->get_var('SELECT post_id FROM '.$wpdb->postmeta.' WHERE meta_key like "_menu_item_menu_item_parent" AND meta_value='.$item->ID.' LIMIT 1');
	//if there is at least one item, then $children variable will contain it's ID (which is of course more than 0)
	if($children > 0)
		//in that case - add the CSS class
		$classlist[] = 'menu-item-ancestor';
	//return class list
	return $classlist;
}

//add filter to nav_menu_css_class list
add_filter('nav_menu_css_class', 'antiaris_add_ancestor_class', 2, 10);



/**
 * Add the .htc file for partial CSS3 support in Internet Explorer
*/
function antiaris_ie_css3(){ ?>
	<!--[if lte IE 8]>
      <style type="text/css" media="screen">
      	.box-shadow, .post-tags a, .homepage_pane img{behavior: url(<?php echo get_template_directory_uri(); ?>/js/PIE.php);}	
      </style>
    <![endif]-->
    <?php
}
add_action('wp_head', 'antiaris_ie_css3');


/**
 * Adds the content panes in the homepage. The homepage panes are only displayed if using a static
 * front page, before the comments. It is also recommended that the comments section is disabled 
 * for the page used as the static front page.
*/
function antiaris_homepage_panes(){
	global $antiaris_settings, $antiaris_defaults;
	
	// Get the number of panes to display
	if ($antiaris_settings['show_post_type'] == 'latest-posts' || $antiaris_settings['show_post_type'] == 'cat-latest-posts'){
		$pane_count = $antiaris_settings['homepage_panes_count'];
	} elseif ($antiaris_settings['show_post_type'] == 'posts') {
		$pane_count = count(explode(',', $antiaris_settings['homepage_panes_posts']));
	}
	
	// Build the common get_posts() parameter first
	$args = array(
				  'orderby' => 'date',
				  'order' => 'DESC',
				  'suppress_filters' => 0,
				  'post_type' => array('post', 'page'),
				 );
	
	// args specific to latest posts
	if ($antiaris_settings['show_post_type'] == 'latest-posts' ){
		$args_merge = array(
							'numberposts' => $pane_count,
							);
		$args = array_merge($args, $args_merge);
	}
	
	// args specific to latest posts by category
	if ($antiaris_settings['show_post_type'] == 'cat-latest-posts' ){
		$args_merge = array(
							'numberposts' => $pane_count,
							'category' => $antiaris_settings['homepage_panes_cat'],
							);
		$args = array_merge($args, $args_merge);
	}
	
	// args specific to posts/pages
	if ($antiaris_settings['show_post_type'] == 'posts' ){
		
		$args_merge = array(
							'numberposts' => $pane_count,
							'include' => $antiaris_settings['homepage_panes_posts'],
							);
		$args = array_merge($args, $args_merge);
	}
	
	global $post;
	
	// Get the posts to display as homepage panes
	$posts = get_posts(apply_filters('antiaris_homepage_panes_args', $args));
	?>
    
    <div class="homepage_panes">
	
	<?php foreach ($posts as $post) : setup_postdata($post);
		 ?>
		<div class="homepage_pane clearfix">
        
        	<a href="<?php the_permalink(); ?>" title="<?php printf(__('Permalink to %s', 'antiaris'), esc_attr(get_the_title())); ?>">
        	<?php /* Get the post's image */ 
			if (has_post_thumbnail($post->ID)) {
				the_post_thumbnail('antiaris-homepage-pane');
			} else {
				echo antiaris_get_post_image($post->ID, 'antiaris-homepage-pane');
			}
			?>
            </a>
            
            <?php /* The post title */ ?>
            <h3 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php printf(__('Permalink to %s', 'antiaris'), esc_attr(get_the_title())); ?>"><?php the_title(); ?></a></h3>
            
            <?php /* The post excerpt */ ?>
            <div class="post-excerpt">
            	<?php the_excerpt(); ?>
            </div>
            
            <?php /* Read more button */ ?>
            <p class="post-comments">
            	<a href="<?php the_permalink(); ?>" title="<?php printf(__('Permalink to %s', 'antiaris'), esc_attr(get_the_title())); ?>"><?php _e('Read more', 'antiaris'); ?></a>
            </p>
        </div>
    <?php endforeach; ?>
	</div>
	
	<?php
}

/* Helper function to control when the homepage panes should be displayed. */
function antiaris_display_homepage_panes(){
	global $antiaris_settings;
	if (get_option('show_on_front') == 'page' && !$antiaris_settings['disable_homepage_panes'] && is_front_page()) {
		antiaris_homepage_panes();
	}	
}
add_action('antiaris_after_loop', 'antiaris_display_homepage_panes');


/**
 * This function outputs a link to the favicon in the page's <head> element,
 * if a favicon URL is present in the options.
*/
function antiaris_favicon(){
	global $antiaris_settings;
	if ($antiaris_settings['favicon_url']) { ?>
		<link rel="icon" href="<?php echo home_url(); ?>/favicon.ico" type="image/x-icon" />
	<?php
    }
}
add_action('wp_head', 'antiaris_favicon');
?>